@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import platform
 import sys
 
 from setuptools import setup
@@ -21,7 +22,13 @@ setup(
         "Operating System :: MacOS :: MacOS X",
     ],
     packages=["rust_with_cffi"],
-    rust_extensions=[RustExtension("rust_with_cffi.rust")],
+    rust_extensions=[
+        RustExtension(
+            "rust_with_cffi.rust",
+            py_limited_api=True,
+            features=[] if platform.python_implementation() == 'PyPy' else ["pyo3/abi3"]
+        ),
+    ],
     cffi_modules=["cffi_module.py:ffi"],
     install_requires=install_requires,
     setup_requires=setup_requires,
